%define sover 3

Name: openssl
Version: 3.0.12
Release: 2
License: Apache-2.0
Summary: Open Source SSL/TLS toolkit
Url: https://www.openssl.org

BuildRequires: zlib-devel
BuildRequires: pase-build-tools
BuildRequires: binutils-gnu

Source0: https://www.openssl.org/source/openssl-%{version}.tar.gz
Source1: openssl-3.0-ibmi.conf

Patch1: openssl-3.0-no-test_shlibload.patch
Patch2: openssl-3.0-aix-gnu-as-support.patch
Patch3: openssl3-CVE-2023-6129.patch
Patch4: openssl3-CVE-2023-6237.patch

%description
OpenSSL is an open source project that provides a robust, commercial-grade, and
full-featured toolkit for the Transport Layer Security (TLS) and Secure Sockets
Layer (SSL) protocols.

It also provides a general-purpose cryptography library.

%package -n libopenssl%{sover}
Summary: OpenSSL 3.x library

%description -n libopenssl%{sover}
OpenSSL 3.x libraries

%package devel
Summary: OpenSSL development files
Requires: libopenssl%{sover} = %{version}
Provides: openssl-3.0-devel = %{version}-%{release}

%description devel
OpenSSL 3.x development files


%prep
%setup -q -n %{name}-%{version}

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

cp %{SOURCE1} Configurations/50-ibmi.conf

mkdir bin
ln -s %{_bindir}/gnu-as bin/as

%build

PATH=$PWD/bin:$PATH

perl ./Configure \
%ifarch ppc64
  pase64-gcc \
%else
  pase-gcc \
%endif
  no-idea \
  no-mdc2 \
  no-rc5 \
  no-hw \
  no-egd \
  enable-tls1_3 \
  shared \
  threads \
  --prefix=%{_prefix} \
  --openssldir=%{_sysconfdir}/ssl \
  -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib \
  -DOPENSSL_NO_SECURE_MEMORY \
  # end


make %_smp_mflags build_libs
ls libcrypto.*
svr4-shrlib libcrypto.so.3 libcrypto.so.3 %{_arch}

rm libssl.so.%{sover}
make %_smp_mflags build_libs
svr4-shrlib libssl.so.%{sover} libssl.so.%{sover} %{_arch}

%make_build


%check

make test


%install

%make_install

rm %{buildroot}/%{_libdir}/*.a

# OpenSSL 3 now makes these a .a -> .so.3 symlink which we removed above
ln -s libssl.so.%{sover} %{buildroot}/%{_libdir}/libssl.so
ln -s libcrypto.so.%{sover} %{buildroot}/%{_libdir}/libcrypto.so

mkdir -p %{buildroot}/%{_datadir}/ssl
mv %{buildroot}%{_sysconfdir}/ssl/misc %{buildroot}/%{_datadir}/ssl

# shipped in ca-certificates
rmdir %{buildroot}%{_sysconfdir}/ssl/certs

%files
%defattr(-, qsys, *none)

%{_bindir}/openssl
%{_bindir}/c_rehash

%{_datadir}/ssl
%{_mandir}/man1/*

%{_sysconfdir}/ssl

%files -n libopenssl%{sover}
%defattr(-, qsys, *none)

%{_libdir}/libcrypto.so.%{sover}
%{_libdir}/libssl.so.%{sover}

%dir %{_libdir}/engines-%{sover}
%{_libdir}/engines-%{sover}/*.so

%{_libdir}/ossl-modules/*.so

%files devel
%defattr(-, qsys, *none)

%{_libdir}/libcrypto.so
%{_libdir}/libssl.so

%{_libdir}/pkgconfig/*

%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man7/*

%{_docdir}/openssl

%{_includedir}/openssl

%changelog
* Tue Jan 16 2024 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.0.12
- Fixes CVE-2023-6129
- Fixes CVE-2023-6237

* Tue Oct 24 2023 Kevin Adler <kadler@us.ibm.com> - 3.0.12
- Bump to 3.0.12
- Fixes CVE-2023-5363

* Tue Aug 01 2023 Kevin Adler <kadler@us.ibm.com> - 3.0.10
- Bump to 3.0.10
- Fixes CVE-2023-0464
- Fixes CVE-2023-0465
- Fixes CVE-2023-0466
- Fixes CVE-2023-1255
- Fixes CVE-2023-3446
- Fixes CVE-2023-3817

* Thu Feb 09 2023 Kevin Adler <kadler@us.ibm.com> - 3.0.8
- Devel package now provides openssl-3.0-devel

* Tue Feb 07 2023 Kevin Adler <kadler@us.ibm.com> - 3.0.8
- Bump to 3.0.8

* Tue Jan 31 2023 Kevin Adler <kadler@us.ibm.com> - 3.0.7
- Initial OpenSSL 3.0 support based on OpenSSL 1.1 spec

